/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   QTreeView *m_view;
};

MainWindow::MainWindow()
{
   QString path;

#ifdef Q_OS_WIN
   QString currentPath = QDir::currentPath();
   path = currentPath.left(currentPath.indexOf('/') + 1);
#else
   path = QDir::homePath();
#endif

   setMinimumSize(700, 500);

   QLabel *label = new QLabel();
   label->setText("File System Tree View \nRoot Path: " + path);
   label->setAlignment(Qt::AlignHCenter);

   QFont font = label->font();
   font.setPointSize(11);
   label->setFont(font);

   QFileSystemModel *model = new QFileSystemModel();
   model->setFilter(QDir::NoDotAndDotDot | QDir::AllDirs | QDir::Files);
   model->setRootPath(path);

   m_view = new QTreeView();
   m_view->setModel(model);
   m_view->setRootIndex(model->index(path));
   m_view->setIndentation(25);

   m_view->setSortingEnabled(true);
   m_view->sortByColumn(0, Qt::AscendingOrder);
   m_view->header()->setSectionResizeMode(QHeaderView::ResizeToContents);

   QPushButton *pb_close = new QPushButton();
   pb_close->setText("Close");

   QHBoxLayout *layout = new QHBoxLayout();
   layout->addStretch();
   layout->addWidget(pb_close);
   layout->addStretch();

   QVBoxLayout *layout_main = new QVBoxLayout(this);
   layout_main->setContentsMargins(20, 20, 20, 15);

   layout_main->addWidget(label);
   layout_main->addSpacing(10);
   layout_main->addWidget(m_view);
   layout_main->addSpacing(10);
   layout_main->addLayout(layout);

   connect(pb_close, &QPushButton::clicked, this, &QWidget::close);
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
